@@ -1,5 +1,12 @@
 from . import architectures  # noqa: F401
 from .models.factory import create_model, create_preprocessing  # noqa: F401
 from .models.registry import list_models  # noqa: F401
-from .utils import get_dir, set_dir  # noqa: F401
+from .utils import (  # noqa: F401
+    cached_model_path,
+    clear_model_cache,
+    get_dir,
+    list_cached_models,
+    set_dir,
+    set_model_cache,
+)
 from .version import __version__  # noqa: F401
